/***********************************************************************
*
* asmfps.h - Floating Point Support routines for the IBM 7090 assembler.
*
* Changes:
*   12/30/04   DGP   Hacked from S709 arith. routines.
*   03/15/05   DGP   Added dblprecision parm to ibm_strtod.
*	
***********************************************************************/

/*
** Misc constants
*/

#define SIGN	0200
#define QCARRY	0040
#define Q	0020
#define P	0010
#define HMSK	0007

#define SEXPMASK 0377
#define FRACMASK 0000777777777
/*                            777777777 */

#define SIGNSHIFT 35
#define EXPSHIFT  27

int ibm_fadd (t_uint64 *, t_uint64 *, int);
int ibm_fmpy (t_uint64 *, t_uint64 *, int);
int ibm_fdiv (t_uint64 *, t_uint64 *);

int ibm_dfadd (t_uint64 *, t_uint64 *, int);
int ibm_dfmpy (t_uint64 *, t_uint64 *, int);
int ibm_dfdiv (t_uint64 *, t_uint64 *);

int ibm_strtod (char *, t_uint64 *, int);
